@@ -27,6 +27,8 @@
 
 #if defined(__linux__)
 
+#include <libxfce4util/libxfce4util.h>
+
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -55,9 +57,12 @@ wi_open(const char *interface)
   g_return_val_if_fail(interface != NULL, NULL);
 
   if ((sock = socket(PF_INET, SOCK_DGRAM, 0)) < 0) {
+    TRACE ("Failed to open socket, %d", sock);
     return(NULL);
   }
 
+  TRACE ("Socket Open for interface %s, %d",interface,sock);
+  
   device = g_new0(struct wi_device, 1);
   device->socket = sock;
   g_strlcpy(device->interface, interface, WI_MAXSTRLEN);
@@ -65,6 +70,12 @@ wi_open(const char *interface)
   return(device);
 }
 
+static void
+close(int fd)
+{
+  shutdown(fd, SHUT_RDWR);
+}
+
 void
 wi_close(struct wi_device *device)
 {
@@ -77,8 +88,11 @@ wi_close(struct wi_device *device)
 int
 wi_query(struct wi_device *device, struct wi_stats *stats)
 {
+#if WIRELESS_EXT <= 11
   char buffer[1024];
   char *bp;
+  FILE *fp;
+#endif
   double link;
   long level;
   int result;
@@ -87,8 +101,6 @@ wi_query(struct wi_device *device, struct wi_stats *stats)
   struct iw_statistics wstats;
   char essid[IW_ESSID_MAX_SIZE + 1];
 
-  FILE *fp;
-
   g_return_val_if_fail(device != NULL, WI_INVAL);
   g_return_val_if_fail(stats != NULL, WI_INVAL);
 
@@ -103,17 +115,21 @@ wi_query(struct wi_device *device, struct wi_stats *stats)
   wreq.u.essid.length = IW_ESSID_MAX_SIZE + 1;
   wreq.u.essid.flags = 0;
   if ((result = ioctl(device->socket, SIOCGIWESSID, &wreq) < 0)) {
+    TRACE ("Couldn't get ESSID");
     g_strlcpy(stats->ws_netname, "", WI_MAXSTRLEN);
   } else {
     /* ESSID is possibly NOT null terminated but we know its length */
     essid[wreq.u.essid.length] = 0;
+    TRACE ("ESSID is %s", essid);
     g_strlcpy(stats->ws_netname, essid, WI_MAXSTRLEN);
   }
 
   /* Get bit rate */
   if ((result = ioctl(device->socket, SIOCGIWRATE, &wreq) < 0)) {
+    TRACE ("Couldn't get bit-rate");
     stats->ws_rate = 0;
   } else {
+    TRACE ("Bit-rate is %d", wreq.u.bitrate.value);
     stats->ws_rate = wreq.u.bitrate.value;
   }
 
@@ -123,6 +139,7 @@ wi_query(struct wi_device *device, struct wi_stats *stats)
   wreq.u.data.length = 0;
   wreq.u.data.flags = 1;
   if ((result = ioctl(device->socket, SIOCGIWSTATS, &wreq)) < 0) {
+    TRACE ("Returning NOSUCHDEV, got %d for socket %d", result, device->socket);
     return(WI_NOSUCHDEV);
   }
   level = wstats.qual.level;
